from PySide6.QtWidgets import QMainWindow, QTextEdit, QPushButton, QVBoxLayout, QWidget
from config.settings import Settings

class MainWindow(QMainWindow):
    def __init__(self, mqtt_client, parser_factory, responder):
        super().__init__()
        self.setWindowTitle("MQTT在线测试平台")
        self.resize(600, 400)
        self.mqtt_client = mqtt_client
        self.parser = parser_factory.get_parser(Settings.PROTOCOL_TYPE)
        self.responder = responder

        self.text_edit = QTextEdit()
        self.btn_connect = QPushButton("连接MQTT")
        self.btn_disconnect = QPushButton("断开MQTT")
        self.btn_connect.clicked.connect(self.connect_mqtt)
        self.btn_disconnect.clicked.connect(self.disconnect_mqtt)

        layout = QVBoxLayout()
        layout.addWidget(self.text_edit)
        layout.addWidget(self.btn_connect)
        layout.addWidget(self.btn_disconnect)

        container = QWidget()
        container.setLayout(layout)
        self.setCentralWidget(container)

    def connect_mqtt(self):
        self.mqtt_client.set_on_message(self.on_message)
        self.mqtt_client.connect()
        self.text_edit.append("已连接MQTT")

    def disconnect_mqtt(self):
        self.mqtt_client.disconnect()
        self.text_edit.append("已断开MQTT")

    def on_message(self, client, userdata, msg):
        try:
            parsed = self.parser.parse(msg.payload)
            self.text_edit.append(f"收到消息: {parsed}")
            self.responder.respond(parsed)
        except Exception as e:
            self.text_edit.append(f"解析错误: {e}") 